# Multiple Choices { points=4 }

## -

Which volcanoes are located in Italy? (multiple answers)

- [x] Etna
- [ ] Krakatoa
- [x] Vesuvius
- [ ] Mauna Loa
- [ ] Fuji
- [x] Stromboli
- [ ] Kilauea

## -

Among these animals, which ones is a mammal?

- [ ] Crocodile
- [x] Dolphin
- [ ] Eagle
- [ ] Penguin
- [ ] Shark

## -

In Common Lisp, what is the result of the following expression?

```lisp
(+ 1 2 (if (> 3 2) 4 5))
```

- [ ] 8
- [x] 7
- [ ] 6
- [ ] 5

## -

What is the correct way of counting the vowels on stdin in Perl?

- [ ] `perl -ne 'print scalar(() = /[aeiou]/gi)'`
- [x] `perl -ne '$count += () = /[aeiou]/gi; END { print $count }'`
- [ ] `perl -pe 's/[^aeiou]//gi; print length'`
- [ ] `perl -e 'while (<>) { $count += length($_) } print $count'`

---
